@@ -1,4 +1,5 @@
 package Bot::BasicBot::Pluggable::Module::Auth;
+$Bot::BasicBot::Pluggable::Module::Auth::VERSION = '0.87';
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
@@ -107,13 +108,12 @@ sub admin {
     elsif ( $body =~ /^!users/ ) {
         return "Users: "
           . join( ", ",
-            map { s/^password_// ? $_ : () }
+            map { my $user = $_; $user =~ s/^password_// ? $user : () }
               $self->store_keys( res => ["^password"] ) )
           . ".";
-
     }
     else {
-        return undef
+        return
           if $self->get("allow_anonymous") || $self->authed( $mess->{who} );
         return "You need to authenticate.";
     }
@@ -135,6 +135,10 @@ __END__
 
 Bot::BasicBot::Pluggable::Module::Auth - authentication for Bot::BasicBot::Pluggable modules
 
+=head1 VERSION
+
+version 0.87
+
 =head1 SYNOPSIS
 
 This module catches messages at priority 1 and stops anything starting
@@ -222,4 +226,4 @@ idea, but is also not an Auth bug, it's an architecture bug.
 Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
+and/or modify it under the same terms as Perl itself.
\ No newline at end of file
