@@ -1,10 +1,9 @@
 package Bot::BasicBot::Pluggable::Module::ChanOp;
+$Bot::BasicBot::Pluggable::Module::ChanOp::VERSION = '0.87';
 use base 'Bot::BasicBot::Pluggable::Module';
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
 sub init {
     my $self = shift;
     $self->config(
@@ -129,6 +128,10 @@ __END__
 
 Bot::BasicBot::Pluggable::Module::ChanOp - Channel operator
 
+=head1 VERSION
+
+version 0.87
+
 =head1 SYNOPSIS
 
   msg> me: !op #botzone
@@ -167,13 +170,9 @@ Maximum numbers of messages per user in C<user_flood_seconds>. Defaults to 6.
 
 C<user_flood_seconds>. Defaults to 6.
 
-=head1 VERSION
-
-0.01
-
 =head1 AUTHOR
 
 Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
+and/or modify it under the same terms as Perl itself.
\ No newline at end of file
