@@ -1,4 +1,5 @@
 package Bot::BasicBot::Pluggable::Module::Google;
+$Bot::BasicBot::Pluggable::Module::Google::VERSION = '0.87';
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
@@ -18,36 +19,48 @@ sub init {
 }
 
 sub help {
-    return "Searches Google for terms and spellings. Usage: google <terms>, spell <words>.";
+    return
+"Searches Google for terms and spellings. Usage: google <terms>, spell <words>.";
 }
 
 sub told {
-    my ($self, $mess) = @_;
+    my ( $self, $mess ) = @_;
     my $body = $mess->{body};
 
-    return if ($self->get("user_require_addressing") and not $mess->{address});
+    return
+      if ( $self->get("user_require_addressing") and not $mess->{address} );
 
-    my ($command, $param) = split(/\s+/, $body, 2);
+    my ( $command, $param ) = split( /\s+/, $body, 2 );
     $command = lc($command);
 
-    if ($command eq "google") {
-        return "No Google key has been set! Set it with '!set Google google_key <key>'." unless $self->get("user_google_key");
-        return "Your configuration has exceeded the maximum number of allowed Google results (10)." if $self->get("user_num_results") > 10;
+    if ( $command eq "google" ) {
+        return
+"No Google key has been set! Set it with '!set Google google_key <key>'."
+          unless $self->get("user_google_key");
+        return
+"Your configuration has exceeded the maximum number of allowed Google results (10)."
+          if $self->get("user_num_results") > 10;
 
-        my $google = Net::Google->new(key=>$self->get("user_google_key"));
-        my $search = $google->search(lr=>qw($self->get("user_languages")), max_results=>$self->get("user_num_results"));
-        $search->query(split(/\s+/, $param));
+        my $google = Net::Google->new( key => $self->get("user_google_key") );
+        my $search = $google->search(
+            lr          => qw($self->get("user_languages")),
+            max_results => $self->get("user_num_results")
+        );
+        $search->query( split( /\s+/, $param ) );
 
-        my $res; # magical concatenation of all results.
-        $res .= $_->title.": ".$_->URL."\n" for @{$search->results()};
-        $res =~ s/<[^>]+>//g; # remove the bolded search terms.
+        my $res;    # magical concatenation of all results.
+        $res .= $_->title . ": " . $_->URL . "\n" for @{ $search->results() };
+        $res =~ s/<[^>]+>//g;    # remove the bolded search terms.
 
         return $res ? $res : "No results for \'$param\'.";
 
-    } elsif ($command eq "spell") {
-        return "No Google key has been set! Set it with '!set Google google_key <key>'." unless $self->get("user_google_key");
-        my $google = Net::Google->new(key=>$self->get("user_google_key"));
-        my $res = $google->spelling(phrase=>$param)->suggest();
+    }
+    elsif ( $command eq "spell" ) {
+        return
+"No Google key has been set! Set it with '!set Google google_key <key>'."
+          unless $self->get("user_google_key");
+        my $google = Net::Google->new( key => $self->get("user_google_key") );
+        my $res = $google->spelling( phrase => $param )->suggest();
         return $res ? $res : "No results for \'$param\'.";
     }
 }
@@ -60,6 +73,10 @@ __END__
 
 Bot::BasicBot::Pluggable::Module::Google - searches Google for terms and spellings
 
+=head1 VERSION
+
+version 0.87
+
 =head1 IRC USAGE
 
 =over 4
@@ -109,5 +126,4 @@ L<http://www.google.com/apis/>
 Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
-
+and/or modify it under the same terms as Perl itself.
\ No newline at end of file
