@@ -1,4 +1,5 @@
 package Bot::BasicBot::Pluggable::Store::Deep;
+$Bot::BasicBot::Pluggable::Store::Deep::VERSION = '0.87';
 use warnings;
 use strict;
 use DBM::Deep;
@@ -9,31 +10,34 @@ sub init {
     my $self = shift;
     delete $self->{type};
     $self->{file} ||= 'bot-basicbot.deep';
-    $self->{_db} = DBM::Deep->new(%$self) || die "Couldn't connect to DB '$self->{file}'";
+    $self->{_db} = DBM::Deep->new(%$self)
+      || die "Couldn't connect to DB '$self->{file}'";
 }
 
 sub set {
-    my ($self, $namespace, $key, $value) = @_;
+    my ( $self, $namespace, $key, $value ) = @_;
     $self->{_db}->{$namespace}->{$key} = $value;
     return $self;
 }
 
 sub get {
-    my ($self, $namespace, $key) = @_;
+    my ( $self, $namespace, $key ) = @_;
     return $self->{_db}->{$namespace}->{$key};
 }
 
 sub unset {
-    my ($self, $namespace, $key) = @_;
+    my ( $self, $namespace, $key ) = @_;
     delete $self->{_db}->{$namespace}->{$key};
 }
 
 sub keys {
-    my ($self, $namespace, %opts) = @_;
+    my ( $self, $namespace, %opts ) = @_;
+
     # no idea why this works
-    return CORE::keys %{$self->{_db}->{$namespace}} unless exists $opts{res} && @{$opts{res}};
-    my $mod = $self->{_db}->{$namespace} || {} ;
-    return $self->_keys_aux($mod, $namespace, %opts);
+    return CORE::keys %{ $self->{_db}->{$namespace} }
+      unless exists $opts{res} && @{ $opts{res} };
+    my $mod = $self->{_db}->{$namespace} || {};
+    return $self->_keys_aux( $mod, $namespace, %opts );
 }
 
 sub namespaces {
@@ -49,6 +53,10 @@ __END__
 
 Bot::BasicBot::Pluggable::Store::Deep - use DBM::Deep to provide a storage backend
 
+=head1 VERSION
+
+version 0.87
+
 =head1 SYNOPSIS
 
   my $store = Bot::BasicBot::Pluggable::Store::Deep->new(
@@ -71,7 +79,4 @@ Simon Wistow <simon@thegestalt.org>
 Copyright 2005, Simon Wistow
 
 This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
-
-
-
+and/or modify it under the same terms as Perl itself.
\ No newline at end of file
