@@ -1,10 +1,9 @@
 package Test::Bot::BasicBot::Pluggable;
+$Test::Bot::BasicBot::Pluggable::VERSION = '0.87';
 use warnings;
 use strict;
 use base qw( Bot::BasicBot::Pluggable );
 
-our $VERSION = '0.1';
-
 sub new {
     my ( $class, %args ) = @_;
     my $bot = $class->SUPER::new(
@@ -60,6 +59,10 @@ __END__
 
 Test::Bot::BasicBot::Pluggable - utilities to aid in testing of Bot::BasicBot::Pluggable modules
 
+=head1 VERSION
+
+version 0.87
+
 =head1 SYNOPSIS
 
   use Test::More;
@@ -129,10 +132,6 @@ for it.
 
 There are no methods to test join, part and emote.
 
-=head1 VERSION
-
-0.1
-
 =head1 AUTHOR
 
 Mario Domgoergen <mdom@cpan.org>
@@ -141,4 +140,4 @@ Mario Domgoergen <mdom@cpan.org>
 
 Copyright 2009 Mario Domgoergen, all rights reserved.
 
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
